@@ -1,12 +1,12 @@
-import os
+from pathlib import Path
 
 import pytest
 
 EXCLUSIVE_SESSION_FLAG = '--exclusive-faker-session'
 SKIP_REASON = (
-    'This test is skipped by default since it depends on changes in the behavior of session-scoped fixtures. '
-    'Use a separate pytest run for tests like this with the "{flag}" flag specified.'
-).format(flag=EXCLUSIVE_SESSION_FLAG)
+    f'This test is skipped by default since it depends on changes in the behavior of session-scoped fixtures. '
+    f'Use a separate pytest run for tests like this with the "{EXCLUSIVE_SESSION_FLAG}" flag specified.'
+)
 
 
 def pytest_addoption(parser):
@@ -20,7 +20,7 @@ def pytest_collection_modifyitems(config, items):
     if config.getoption(EXCLUSIVE_SESSION_FLAG):
         return
     skip_lacks_exclusive_session = pytest.mark.skip(reason=SKIP_REASON)
-    session_overrides_dir = os.path.abspath(os.path.join(__file__, '..'))
+    session_overrides_dir = Path(__file__).resolve().parent
     for item in items:
-        if str(item.fspath).startswith(session_overrides_dir):
+        if str(item.fspath).startswith(str(session_overrides_dir)):
             item.add_marker(skip_lacks_exclusive_session)
